use 5.008004;
use ExtUtils::MakeMaker;

WriteMakefile(
  NAME             => 'AsposeSlidesCloud::SlidesApi',
  VERSION_FROM     => 'lib/AsposeSlidesCloud/SlidesApi.pm',
  ABSTRACT         => 'Aspose.Slides Cloud SDK',
  AUTHOR           => 'Victor Putrov',
  LICENSE          => 'MIT',
  MIN_PERL_VERSION => '5.008004'
);